@@ -1,7 +1,7 @@
 #
 # This file is part of Getopt-Mini
 #
-# This software is copyright (c) 2013 by Rodrigo de Oliveira.
+# This software is copyright (c) 2015 by Rodrigo de Oliveira.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -9,10 +9,10 @@
 package Getopt::Mini;
 use strict;
 use warnings;
-use utf8::all;
- 
-our $VERSION = '0.02';
- 
+use Encode qw();
+
+our $VERSION = '0.03';
+
 sub import {
     my $class = shift;
     my %args = @_;
@@ -23,7 +23,7 @@ sub import {
         }
         my %hash = getopt( arrays=>0 );
         no strict 'refs';
-        *{ $args{var} } = \%hash; 
+        *{ $args{var} } = \%hash;
     }
     elsif( defined $args{later} ) {
         # import getopt() so that user can call it
@@ -48,12 +48,12 @@ sub getopt {
     my %opts;
     # get my own opts
     my @argv = @_ == 0
-      ? @ARGV 
+      ? @ARGV
       : do {
-           %opts = @_; 
+           %opts = @_;
            @{ delete $opts{argv} || [] };
       };
-    @argv = @ARGV unless @argv > 0;
+    if (not @argv){ push(@argv, Encode::decode('UTF-8' ,$_) ) for @ARGV; }
     return () unless @argv;
     $hash{_argv} = [ @argv ];
     while(@argv) {
@@ -90,7 +90,7 @@ sub getopt {
         if( @{ $hash{$_} } == 0 ) {
             $hash{$_} = $opts{define} ? 1 : ();
         } elsif( @{ $hash{$_} } == 1 ) {
-            $hash{$_} = $hash{$_}->[0]; 
+            $hash{$_} = $hash{$_}->[0];
         }
     }
     if( defined wantarray ) {
@@ -108,20 +108,22 @@ sub getopt_validate {
     @_ = ($rule, %ARGV );
     goto \&Data::Validator::validate;
 }
- 
+
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Getopt::Mini
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -130,12 +132,20 @@ version 0.02
 
 =head1 DESCRIPTION
 
-This is, yup, yet another Getopt module, a very lightweight one. It's not declarative 
+This is, yup, yet another Getopt module, a very lightweight one. It's not declarative
 in any way, ie, it does not support specs, like L<Getopt::Long> et al do.
 
-On the other hand, it can validate your parameters using the L<Data::Validator> syntax. 
+On the other hand, it can validate your parameters using the L<Data::Validator> syntax.
 But that's a hidden feature for now (you'll need to install L<Data::Validator> yourself
-and find a way to run it by reading this source code). 
+and find a way to run it by reading this source code).
+
+=head1 NAME
+
+Getopt::Mini
+
+=head1 VERSION
+
+version 0.02
 
 =head1 NAME
 
@@ -149,16 +159,16 @@ version 0.02
 
 The rules:
 
-    * -<char>              
+    * -<char>
         does not consume barewords (ie. -f, -h, ...)
         unless you set hungry_flags=>1
 
     * -<str> <bareword>
-    * --<str> <bareword>  
+    * --<str> <bareword>
         will eat up the next bare word (-type f, --file f.txt)
 
-    * -<char|str>=<val> and --<str>=<val> 
-        consumes its value and nothing more 
+    * -<char|str>=<val> and --<str>=<val>
+        consumes its value and nothing more
 
     * <str>
         gets pushed into an array in $ARGV{''}
@@ -170,17 +180,17 @@ Some code examples:
     say YAML::Dump \%ARGV;
     ---
     h: 1
-    file: 
+    file:
       - foo
       - bar
-    
+
     # single flags like -h are checked with exists:
-    
+
     say 'help...' if exists $ARGV{'h'};
 
     # barewords are pushed into the key '_'
-    
-    perl myprog.pl file1.c file2.c 
+
+    perl myprog.pl file1.c file2.c
     say "file: $_" for @{ $ARGV{''} };
 
 Or you can just use a modular version:
@@ -196,18 +206,18 @@ There's also a special mode that can be set with C<array => 1> that will
 make a flag consume all following barewords:
 
     perl myprog.pl -a -b --files f1.txt f2.txt
-    use Getopt::Mini array => 1; 
+    use Getopt::Mini array => 1;
     say YAML::Dump \%ARGV;
     ---
     h: ~
-    file: 
+    file:
       - foo
       - bar
 
 =head1 BUGS
 
 This is *ALPHA* software. And despite its small footprint,
-this is lurking with nasty bugs and potential api changes. 
+this is lurking with nasty bugs and potential api changes.
 
 Complaints should be filed to the Getopt Foundation, which
 has been treating severe NIH syndrome since 1980.
@@ -216,9 +226,9 @@ has been treating severe NIH syndrome since 1980.
 
 L<Getopt::Whatever> - no declarative spec like this module,
 but the options in %ARGV and @ARGV are not where I expect them
-to be. 
+to be.
 
-L<Getopt::Casual> - similar to this module, but very keen on 
+L<Getopt::Casual> - similar to this module, but very keen on
 turning entries into single param options.
 
 =head1 AUTHOR
@@ -232,4 +242,15 @@ This software is copyright (c) 2013 by Rodrigo de Oliveira.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHOR
+
+Rodrigo de Oliveira <rodrigolive@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Rodrigo de Oliveira.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
